@@ -448,7 +448,54 @@ libanjuta_iface_cclosure_marshal_VOID__STRING_STRING_STRING (GClosure     *closu
             data2);
 }
 
-/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:17) */
+/* VOID:STRING,STRING,STRING,STRING,BOOLEAN,BOOLEAN,STRING (./libanjuta-iface-marshallers.list:17) */
+void
+libanjuta_iface_cclosure_marshal_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING (GClosure     *closure,
+                                                                                           GValue       *return_value G_GNUC_UNUSED,
+                                                                                           guint         n_param_values,
+                                                                                           const GValue *param_values,
+                                                                                           gpointer      invocation_hint G_GNUC_UNUSED,
+                                                                                           gpointer      marshal_data)
+{
+  typedef void (*GMarshalFunc_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING) (gpointer     data1,
+                                                                                         gpointer     arg_1,
+                                                                                         gpointer     arg_2,
+                                                                                         gpointer     arg_3,
+                                                                                         gpointer     arg_4,
+                                                                                         gboolean     arg_5,
+                                                                                         gboolean     arg_6,
+                                                                                         gpointer     arg_7,
+                                                                                         gpointer     data2);
+  register GMarshalFunc_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+
+  g_return_if_fail (n_param_values == 8);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_VOID__STRING_STRING_STRING_STRING_BOOLEAN_BOOLEAN_STRING) (marshal_data ? marshal_data : cc->callback);
+
+  callback (data1,
+            g_marshal_value_peek_string (param_values + 1),
+            g_marshal_value_peek_string (param_values + 2),
+            g_marshal_value_peek_string (param_values + 3),
+            g_marshal_value_peek_string (param_values + 4),
+            g_marshal_value_peek_boolean (param_values + 5),
+            g_marshal_value_peek_boolean (param_values + 6),
+            g_marshal_value_peek_string (param_values + 7),
+            data2);
+}
+
+/* VOID:UINT,INT (./libanjuta-iface-marshallers.list:18) */
 void
 libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
                                                  GValue       *return_value G_GNUC_UNUSED,
@@ -485,7 +532,7 @@ libanjuta_iface_cclosure_marshal_VOID__UINT_INT (GClosure     *closure,
             data2);
 }
 
-/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:18) */
+/* VOID:ULONG,STRING,UINT (./libanjuta-iface-marshallers.list:19) */
 void
 libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
                                                           GValue       *return_value G_GNUC_UNUSED,
@@ -524,5 +571,5 @@ libanjuta_iface_cclosure_marshal_VOID__ULONG_STRING_UINT (GClosure     *closure,
             data2);
 }
 
-/* VOID:VOID (./libanjuta-iface-marshallers.list:19) */
+/* VOID:VOID (./libanjuta-iface-marshallers.list:20) */
 
